==> xlr-github-plugin-23.3.0-rc.5.jar: github/commitFiles.py <==
#
# Copyright 2020 XEBIALABS
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

import com.dai.github.JGitClient as JGitClient
from com.xebialabs.xlrelease.scm.connector import GitClient, GitConnectionSettings

connectionSettings = GitConnectionSettings(None, None, None, server['loginOrToken'], server['password'], None, None, None, None, None, None, None, None)
client = GitClient(connectionSettings)

output = JGitClient.stageAndCommitFiles(localPath, server["loginOrToken"], server["password"], files,
                               commitMessage, push)

client.removeCurrentGitConnectionSettings()

==> xlr-github-plugin-25.1.0-1030.113.jar: github/commitFiles.py <==
#
# Copyright 2020 XEBIALABS
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

import com.dai.github.JGitClient as JGitClient
from com.xebialabs.xlrelease.scm.connector import GitClient, GitConnectionSettings
from com.xebialabs.deployit.util import PasswordEncrypter

if PasswordEncrypter.getInstance().isEncrypted(server['loginOrToken']):
    server['loginOrToken'] = PasswordEncrypter.getInstance().decrypt(server['loginOrToken'])

connectionSettings = GitConnectionSettings(None, None, None, server['loginOrToken'], server['password'], None, None, None, None, None, None, None, None)
client = GitClient(connectionSettings)

output = JGitClient.stageAndCommitFiles(localPath, server["loginOrToken"], server["password"], files,
                               commitMessage, push)

client.removeCurrentGitConnectionSettings()
